::: upbankapi.models.AccountType
    rendering:
      show_if_no_docstring: true

::: upbankapi.models.OwnershipType
    rendering:
      show_if_no_docstring: true

::: upbankapi.models.TransactionStatus
    rendering:
      show_if_no_docstring: true

::: upbankapi.models.CardPurchaseMethodEnum
    rendering:
      show_if_no_docstring: true

::: upbankapi.models.WebhookDeliveryStatus
    rendering:
      show_if_no_docstring: true

::: upbankapi.models.WebhookEventType
    rendering:
      show_if_no_docstring: true
